@@ -16,7 +16,9 @@ Usage::
     session_client: ImagebuilderClient = session.client("imagebuilder")
     ```
 """
-from mypy_boto3_imagebuilder.client import ImagebuilderClient as Client, ImagebuilderClient
+from mypy_boto3_imagebuilder.client import ImagebuilderClient
+
+Client = ImagebuilderClient
 
 
 __all__ = ("Client", "ImagebuilderClient")
